import { LogLevel } from '@genesislcap/foundation-logger';
/**
 * @public
 * enum for different types of notification events
 */
export declare enum NotificationEvent {
    NOTIFICATION_EVENT = "notification-event"
}
/**
 * @public
 * type for notification
 */
export type NotificationType = 'error' | 'warning' | 'success';
/**
 * @public
 * type for notification position
 */
export type ToastPosition = 'top-left' | 'top-right' | 'bottom-left' | 'bottom-right';
/**
 * type for notification severity
 * @public
 */
export type NotificationSeverity = 'Information' | 'Warning' | 'Serious' | 'Critical';
/**
 * Interface for notify data
 * @public
 */
export interface NotificationDataRow {
    ALERT_ID: string;
    CREATED_AT: number;
    DETAILS: {
        OPERATION: string;
        ROW_REF: string;
    };
    HEADER: string;
    MESSAGE: string;
    NOTIFY_SEVERITY: NotificationSeverity;
    EXPIRY?: number;
    SENDER?: null;
    USER_NAME: string;
    TABLE_ENTITY_ID: string;
    TOPIC: string;
}
/**
 * Interface for ToastButton
 * @public
 */
export interface ToastButton {
    action({ details, buttonElement, toastElement, }: {
        details: NotificationDataRow;
        buttonElement: HTMLElement;
        toastElement: any;
    }): void;
    condition({ details }?: {
        details: NotificationDataRow;
    }): boolean;
    placeholder?: string;
    appearance?: string;
}
/**
 * Interface for Toast configuration
 * @public
 */
export interface Toast {
    readonly position?: ToastPosition;
    readonly type?: NotificationType;
    readonly autoClose?: boolean;
    readonly closeTimeout?: number;
    readonly details?: NotificationDataRow;
    readonly buttons?: ToastButton[];
}
/**
 * Interface for Dismissing Action configuration
 * @public
 */
export interface DismissingAction {
    readonly label: String;
    readonly action?: Function;
}
/**
 * Interface for Confirming Action configuration
 * @public
 */
export interface ConfirmingAction {
    readonly label: String;
    readonly action: Function;
}
/**
 * Interface for Dialog configuration
 * @public
 */
export interface Dialog {
    readonly confirmingActions?: Array<ConfirmingAction>;
    readonly dismissingAction?: DismissingAction;
}
/**
 * Interface for Banner configuration
 * @public
 */
export interface Banner {
    readonly dismissingAction?: DismissingAction;
    readonly confirmingActions?: Array<ConfirmingAction>;
}
/**
 * @public
 * type for snackbar type
 */
export type SnackbarType = 'error';
/**
 * Interface for Snackbar configuration
 * @public
 */
export interface Snackbar {
    readonly type?: SnackbarType;
    readonly confirmingActions?: Array<ConfirmingAction>;
}
/**
 * Interface for Notification Structure
 *  @public
 */
export interface NotificationStructure {
    readonly title?: string;
    readonly body: string;
    readonly createdAt?: Date;
    readonly logLevel?: LogLevel;
    readonly config?: {
        /**
         * @deprecated Use logLevel from the top level instead
         */
        readonly logLevel?: LogLevel;
        readonly alert?: boolean;
        readonly toast?: Toast;
        readonly banner?: Banner;
        readonly snackbar?: Snackbar;
        readonly dialog?: Dialog;
    };
}
/**
 * Interface for Alert Structure
 *  @public
 */
export interface AlertStructure {
    readonly title: string;
    readonly body: string;
    readonly logLevel?: LogLevel;
}
/**
 * Interface for Banner Structure
 *  @public
 */
export interface BannerStructure {
    readonly body: string;
    readonly logLevel?: LogLevel;
    readonly banner?: Banner;
}
/**
 * Interface for Dialog Structure
 *  @public
 */
export interface DialogStructure {
    readonly title: string;
    readonly body: string;
    readonly logLevel?: LogLevel;
    readonly dialog?: Dialog;
}
/**
 * Interface for Snackbar Structure
 *  @public
 */
export interface SnackbarStructure {
    readonly body: string;
    readonly logLevel?: LogLevel;
    readonly snackbar?: Snackbar;
}
/**
 * Interface for Toast Structure
 *  @public
 */
export interface ToastStructure {
    readonly title: string;
    readonly body: string;
    readonly createdAt?: Date;
    readonly logLevel?: LogLevel;
    readonly toast?: Toast;
}
/**
 * @internal
 */
export type NotificationElement = HTMLElement & {
    notification: NotificationStructure;
};
/**
 * @internal
 */
export type DialogElement = NotificationElement & {
    show: Function;
};
//# sourceMappingURL=types.d.ts.map